==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/AttrOverrideSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class AttrOverrideSpecFluent<A extends AttrOverrideSpecFluent<A>> extends BaseFluent<A>{
  public AttrOverrideSpecFluent() {
  }
  
  public AttrOverrideSpecFluent(AttrOverrideSpec instance) {
    this.copyInstance(instance);
  }
  private TimespecBuilder atime;
  private Long blocks;
  private TimespecBuilder ctime;
  private Long gid;
  private Long ino;
  private String kind;
  private TimespecBuilder mtime;
  private Long nlink;
  private Integer perm;
  private Long rdev;
  private Long size;
  private Long uid;
  
  protected void copyInstance(AttrOverrideSpec instance) {
    instance = (instance != null ? instance : new AttrOverrideSpec());
  
    if (instance != null) {
        this.withAtime(instance.getAtime());
        this.withBlocks(instance.getBlocks());
        this.withCtime(instance.getCtime());
        this.withGid(instance.getGid());
        this.withIno(instance.getIno());
        this.withKind(instance.getKind());
        this.withMtime(instance.getMtime());
        this.withNlink(instance.getNlink());
        this.withPerm(instance.getPerm());
        this.withRdev(instance.getRdev());
        this.withSize(instance.getSize());
        this.withUid(instance.getUid());
        this.withAtime(instance.getAtime());
        this.withBlocks(instance.getBlocks());
        this.withCtime(instance.getCtime());
        this.withGid(instance.getGid());
        this.withIno(instance.getIno());
        this.withKind(instance.getKind());
        this.withMtime(instance.getMtime());
        this.withNlink(instance.getNlink());
        this.withPerm(instance.getPerm());
        this.withRdev(instance.getRdev());
        this.withSize(instance.getSize());
        this.withUid(instance.getUid());
      }
  }
  
  public Timespec buildAtime() {
    return this.atime!=null ?this.atime.build():null;
  }
  
  public A withAtime(Timespec atime) {
    _visitables.get("atime").remove(this.atime);
    if (atime!=null){ this.atime= new TimespecBuilder(atime); _visitables.get("atime").add(this.atime);} else { this.atime = null; _visitables.get("atime").remove(this.atime); } return (A) this;
  }
  
  public boolean hasAtime() {
    return this.atime != null;
  }
  
  public A withNewAtime(Long nsec,Long sec) {
    return (A)withAtime(new Timespec(nsec, sec));
  }
  
  public AtimeNested<A> withNewAtime() {
    return new AtimeNested(null);
  }
  
  public AtimeNested<A> withNewAtimeLike(Timespec item) {
    return new AtimeNested(item);
  }
  
  public AtimeNested<A> editAtime() {
    return withNewAtimeLike(java.util.Optional.ofNullable(buildAtime()).orElse(null));
  }
  
  public AtimeNested<A> editOrNewAtime() {
    return withNewAtimeLike(java.util.Optional.ofNullable(buildAtime()).orElse(new TimespecBuilder().build()));
  }
  
  public AtimeNested<A> editOrNewAtimeLike(Timespec item) {
    return withNewAtimeLike(java.util.Optional.ofNullable(buildAtime()).orElse(item));
  }
  
  public Long getBlocks() {
    return this.blocks;
  }
  
  public A withBlocks(Long blocks) {
    this.blocks=blocks; return (A) this;
  }
  
  public boolean hasBlocks() {
    return this.blocks != null;
  }
  
  public Timespec buildCtime() {
    return this.ctime!=null ?this.ctime.build():null;
  }
  
  public A withCtime(Timespec ctime) {
    _visitables.get("ctime").remove(this.ctime);
    if (ctime!=null){ this.ctime= new TimespecBuilder(ctime); _visitables.get("ctime").add(this.ctime);} else { this.ctime = null; _visitables.get("ctime").remove(this.ctime); } return (A) this;
  }
  
  public boolean hasCtime() {
    return this.ctime != null;
  }
  
  public A withNewCtime(Long nsec,Long sec) {
    return (A)withCtime(new Timespec(nsec, sec));
  }
  
  public CtimeNested<A> withNewCtime() {
    return new CtimeNested(null);
  }
  
  public CtimeNested<A> withNewCtimeLike(Timespec item) {
    return new CtimeNested(item);
  }
  
  public CtimeNested<A> editCtime() {
    return withNewCtimeLike(java.util.Optional.ofNullable(buildCtime()).orElse(null));
  }
  
  public CtimeNested<A> editOrNewCtime() {
    return withNewCtimeLike(java.util.Optional.ofNullable(buildCtime()).orElse(new TimespecBuilder().build()));
  }
  
  public CtimeNested<A> editOrNewCtimeLike(Timespec item) {
    return withNewCtimeLike(java.util.Optional.ofNullable(buildCtime()).orElse(item));
  }
  
  public Long getGid() {
    return this.gid;
  }
  
  public A withGid(Long gid) {
    this.gid=gid; return (A) this;
  }
  
  public boolean hasGid() {
    return this.gid != null;
  }
  
  public Long getIno() {
    return this.ino;
  }
  
  public A withIno(Long ino) {
    this.ino=ino; return (A) this;
  }
  
  public boolean hasIno() {
    return this.ino != null;
  }
  
  public String getKind() {
    return this.kind;
  }
  
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  
  public boolean hasKind() {
    return this.kind != null;
  }
  
  public Timespec buildMtime() {
    return this.mtime!=null ?this.mtime.build():null;
  }
  
  public A withMtime(Timespec mtime) {
    _visitables.get("mtime").remove(this.mtime);
    if (mtime!=null){ this.mtime= new TimespecBuilder(mtime); _visitables.get("mtime").add(this.mtime);} else { this.mtime = null; _visitables.get("mtime").remove(this.mtime); } return (A) this;
  }
  
  public boolean hasMtime() {
    return this.mtime != null;
  }
  
  public A withNewMtime(Long nsec,Long sec) {
    return (A)withMtime(new Timespec(nsec, sec));
  }
  
  public MtimeNested<A> withNewMtime() {
    return new MtimeNested(null);
  }
  
  public MtimeNested<A> withNewMtimeLike(Timespec item) {
    return new MtimeNested(item);
  }
  
  public MtimeNested<A> editMtime() {
    return withNewMtimeLike(java.util.Optional.ofNullable(buildMtime()).orElse(null));
  }
  
  public MtimeNested<A> editOrNewMtime() {
    return withNewMtimeLike(java.util.Optional.ofNullable(buildMtime()).orElse(new TimespecBuilder().build()));
  }
  
  public MtimeNested<A> editOrNewMtimeLike(Timespec item) {
    return withNewMtimeLike(java.util.Optional.ofNullable(buildMtime()).orElse(item));
  }
  
  public Long getNlink() {
    return this.nlink;
  }
  
  public A withNlink(Long nlink) {
    this.nlink=nlink; return (A) this;
  }
  
  public boolean hasNlink() {
    return this.nlink != null;
  }
  
  public Integer getPerm() {
    return this.perm;
  }
  
  public A withPerm(Integer perm) {
    this.perm=perm; return (A) this;
  }
  
  public boolean hasPerm() {
    return this.perm != null;
  }
  
  public Long getRdev() {
    return this.rdev;
  }
  
  public A withRdev(Long rdev) {
    this.rdev=rdev; return (A) this;
  }
  
  public boolean hasRdev() {
    return this.rdev != null;
  }
  
  public Long getSize() {
    return this.size;
  }
  
  public A withSize(Long size) {
    this.size=size; return (A) this;
  }
  
  public boolean hasSize() {
    return this.size != null;
  }
  
  public Long getUid() {
    return this.uid;
  }
  
  public A withUid(Long uid) {
    this.uid=uid; return (A) this;
  }
  
  public boolean hasUid() {
    return this.uid != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AttrOverrideSpecFluent that = (AttrOverrideSpecFluent) o;
    if (!java.util.Objects.equals(atime, that.atime)) return false;
  
    if (!java.util.Objects.equals(blocks, that.blocks)) return false;
  
    if (!java.util.Objects.equals(ctime, that.ctime)) return false;
  
    if (!java.util.Objects.equals(gid, that.gid)) return false;
  
    if (!java.util.Objects.equals(ino, that.ino)) return false;
  
    if (!java.util.Objects.equals(kind, that.kind)) return false;
  
    if (!java.util.Objects.equals(mtime, that.mtime)) return false;
  
    if (!java.util.Objects.equals(nlink, that.nlink)) return false;
  
    if (!java.util.Objects.equals(perm, that.perm)) return false;
  
    if (!java.util.Objects.equals(rdev, that.rdev)) return false;
  
    if (!java.util.Objects.equals(size, that.size)) return false;
  
    if (!java.util.Objects.equals(uid, that.uid)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(atime,  blocks,  ctime,  gid,  ino,  kind,  mtime,  nlink,  perm,  rdev,  size,  uid,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (atime != null) { sb.append("atime:"); sb.append(atime + ","); }
    if (blocks != null) { sb.append("blocks:"); sb.append(blocks + ","); }
    if (ctime != null) { sb.append("ctime:"); sb.append(ctime + ","); }
    if (gid != null) { sb.append("gid:"); sb.append(gid + ","); }
    if (ino != null) { sb.append("ino:"); sb.append(ino + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (mtime != null) { sb.append("mtime:"); sb.append(mtime + ","); }
    if (nlink != null) { sb.append("nlink:"); sb.append(nlink + ","); }
    if (perm != null) { sb.append("perm:"); sb.append(perm + ","); }
    if (rdev != null) { sb.append("rdev:"); sb.append(rdev + ","); }
    if (size != null) { sb.append("size:"); sb.append(size + ","); }
    if (uid != null) { sb.append("uid:"); sb.append(uid); }
    sb.append("}");
    return sb.toString();
  }
  public class AtimeNested<N> extends TimespecFluent<AtimeNested<N>> implements Nested<N>{
    AtimeNested(Timespec item) {
      this.builder = new TimespecBuilder(this, item);
    }
    TimespecBuilder builder;
    
    public N and() {
      return (N) AttrOverrideSpecFluent.this.withAtime(builder.build());
    }
    
    public N endAtime() {
      return and();
    }
    
  
  }
  public class CtimeNested<N> extends TimespecFluent<CtimeNested<N>> implements Nested<N>{
    CtimeNested(Timespec item) {
      this.builder = new TimespecBuilder(this, item);
    }
    TimespecBuilder builder;
    
    public N and() {
      return (N) AttrOverrideSpecFluent.this.withCtime(builder.build());
    }
    
    public N endCtime() {
      return and();
    }
    
  
  }
  public class MtimeNested<N> extends TimespecFluent<MtimeNested<N>> implements Nested<N>{
    MtimeNested(Timespec item) {
      this.builder = new TimespecBuilder(this, item);
    }
    TimespecBuilder builder;
    
    public N and() {
      return (N) AttrOverrideSpecFluent.this.withMtime(builder.build());
    }
    
    public N endMtime() {
      return and();
    }
    
  
  }

}

==> chaosmesh-model-6.9.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/AttrOverrideSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class AttrOverrideSpecFluent<A extends AttrOverrideSpecFluent<A>> extends BaseFluent<A>{
  public AttrOverrideSpecFluent() {
  }
  
  public AttrOverrideSpecFluent(AttrOverrideSpec instance) {
    this.copyInstance(instance);
  }
  private TimespecBuilder atime;
  private Long blocks;
  private TimespecBuilder ctime;
  private Long gid;
  private Long ino;
  private String kind;
  private TimespecBuilder mtime;
  private Long nlink;
  private Integer perm;
  private Long rdev;
  private Long size;
  private Long uid;
  
  protected void copyInstance(AttrOverrideSpec instance) {
    instance = (instance != null ? instance : new AttrOverrideSpec());
    if (instance != null) {
          this.withAtime(instance.getAtime());
          this.withBlocks(instance.getBlocks());
          this.withCtime(instance.getCtime());
          this.withGid(instance.getGid());
          this.withIno(instance.getIno());
          this.withKind(instance.getKind());
          this.withMtime(instance.getMtime());
          this.withNlink(instance.getNlink());
          this.withPerm(instance.getPerm());
          this.withRdev(instance.getRdev());
          this.withSize(instance.getSize());
          this.withUid(instance.getUid());
          this.withAtime(instance.getAtime());
          this.withBlocks(instance.getBlocks());
          this.withCtime(instance.getCtime());
          this.withGid(instance.getGid());
          this.withIno(instance.getIno());
          this.withKind(instance.getKind());
          this.withMtime(instance.getMtime());
          this.withNlink(instance.getNlink());
          this.withPerm(instance.getPerm());
          this.withRdev(instance.getRdev());
          this.withSize(instance.getSize());
          this.withUid(instance.getUid());
        }
  }
  
  public Timespec buildAtime() {
    return this.atime != null ? this.atime.build() : null;
  }
  
  public A withAtime(Timespec atime) {
    this._visitables.remove(this.atime);
    if (atime != null) {
        this.atime = new TimespecBuilder(atime);
        this._visitables.get("atime").add(this.atime);
    } else {
        this.atime = null;
        this._visitables.get("atime").remove(this.atime);
    }
    return (A) this;
  }
  
  public boolean hasAtime() {
    return this.atime != null;
  }
  
  public A withNewAtime(Long nsec,Long sec) {
    return (A)withAtime(new Timespec(nsec, sec));
  }
  
  public AtimeNested<A> withNewAtime() {
    return new AtimeNested(null);
  }
  
  public AtimeNested<A> withNewAtimeLike(Timespec item) {
    return new AtimeNested(item);
  }
  
  public AtimeNested<A> editAtime() {
    return withNewAtimeLike(java.util.Optional.ofNullable(buildAtime()).orElse(null));
  }
  
  public AtimeNested<A> editOrNewAtime() {
    return withNewAtimeLike(java.util.Optional.ofNullable(buildAtime()).orElse(new TimespecBuilder().build()));
  }
  
  public AtimeNested<A> editOrNewAtimeLike(Timespec item) {
    return withNewAtimeLike(java.util.Optional.ofNullable(buildAtime()).orElse(item));
  }
  
  public Long getBlocks() {
    return this.blocks;
  }
  
  public A withBlocks(Long blocks) {
    this.blocks = blocks;
    return (A) this;
  }
  
  public boolean hasBlocks() {
    return this.blocks != null;
  }
  
  public Timespec buildCtime() {
    return this.ctime != null ? this.ctime.build() : null;
  }
  
  public A withCtime(Timespec ctime) {
    this._visitables.remove(this.ctime);
    if (ctime != null) {
        this.ctime = new TimespecBuilder(ctime);
        this._visitables.get("ctime").add(this.ctime);
    } else {
        this.ctime = null;
        this._visitables.get("ctime").remove(this.ctime);
    }
    return (A) this;
  }
  
  public boolean hasCtime() {
    return this.ctime != null;
  }
  
  public A withNewCtime(Long nsec,Long sec) {
    return (A)withCtime(new Timespec(nsec, sec));
  }
  
  public CtimeNested<A> withNewCtime() {
    return new CtimeNested(null);
  }
  
  public CtimeNested<A> withNewCtimeLike(Timespec item) {
    return new CtimeNested(item);
  }
  
  public CtimeNested<A> editCtime() {
    return withNewCtimeLike(java.util.Optional.ofNullable(buildCtime()).orElse(null));
  }
  
  public CtimeNested<A> editOrNewCtime() {
    return withNewCtimeLike(java.util.Optional.ofNullable(buildCtime()).orElse(new TimespecBuilder().build()));
  }
  
  public CtimeNested<A> editOrNewCtimeLike(Timespec item) {
    return withNewCtimeLike(java.util.Optional.ofNullable(buildCtime()).orElse(item));
  }
  
  public Long getGid() {
    return this.gid;
  }
  
  public A withGid(Long gid) {
    this.gid = gid;
    return (A) this;
  }
  
  public boolean hasGid() {
    return this.gid != null;
  }
  
  public Long getIno() {
    return this.ino;
  }
  
  public A withIno(Long ino) {
    this.ino = ino;
    return (A) this;
  }
  
  public boolean hasIno() {
    return this.ino != null;
  }
  
  public String getKind() {
    return this.kind;
  }
  
  public A withKind(String kind) {
    this.kind = kind;
    return (A) this;
  }
  
  public boolean hasKind() {
    return this.kind != null;
  }
  
  public Timespec buildMtime() {
    return this.mtime != null ? this.mtime.build() : null;
  }
  
  public A withMtime(Timespec mtime) {
    this._visitables.remove(this.mtime);
    if (mtime != null) {
        this.mtime = new TimespecBuilder(mtime);
        this._visitables.get("mtime").add(this.mtime);
    } else {
        this.mtime = null;
        this._visitables.get("mtime").remove(this.mtime);
    }
    return (A) this;
  }
  
  public boolean hasMtime() {
    return this.mtime != null;
  }
  
  public A withNewMtime(Long nsec,Long sec) {
    return (A)withMtime(new Timespec(nsec, sec));
  }
  
  public MtimeNested<A> withNewMtime() {
    return new MtimeNested(null);
  }
  
  public MtimeNested<A> withNewMtimeLike(Timespec item) {
    return new MtimeNested(item);
  }
  
  public MtimeNested<A> editMtime() {
    return withNewMtimeLike(java.util.Optional.ofNullable(buildMtime()).orElse(null));
  }
  
  public MtimeNested<A> editOrNewMtime() {
    return withNewMtimeLike(java.util.Optional.ofNullable(buildMtime()).orElse(new TimespecBuilder().build()));
  }
  
  public MtimeNested<A> editOrNewMtimeLike(Timespec item) {
    return withNewMtimeLike(java.util.Optional.ofNullable(buildMtime()).orElse(item));
  }
  
  public Long getNlink() {
    return this.nlink;
  }
  
  public A withNlink(Long nlink) {
    this.nlink = nlink;
    return (A) this;
  }
  
  public boolean hasNlink() {
    return this.nlink != null;
  }
  
  public Integer getPerm() {
    return this.perm;
  }
  
  public A withPerm(Integer perm) {
    this.perm = perm;
    return (A) this;
  }
  
  public boolean hasPerm() {
    return this.perm != null;
  }
  
  public Long getRdev() {
    return this.rdev;
  }
  
  public A withRdev(Long rdev) {
    this.rdev = rdev;
    return (A) this;
  }
  
  public boolean hasRdev() {
    return this.rdev != null;
  }
  
  public Long getSize() {
    return this.size;
  }
  
  public A withSize(Long size) {
    this.size = size;
    return (A) this;
  }
  
  public boolean hasSize() {
    return this.size != null;
  }
  
  public Long getUid() {
    return this.uid;
  }
  
  public A withUid(Long uid) {
    this.uid = uid;
    return (A) this;
  }
  
  public boolean hasUid() {
    return this.uid != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AttrOverrideSpecFluent that = (AttrOverrideSpecFluent) o;
    if (!java.util.Objects.equals(atime, that.atime)) return false;
    if (!java.util.Objects.equals(blocks, that.blocks)) return false;
    if (!java.util.Objects.equals(ctime, that.ctime)) return false;
    if (!java.util.Objects.equals(gid, that.gid)) return false;
    if (!java.util.Objects.equals(ino, that.ino)) return false;
    if (!java.util.Objects.equals(kind, that.kind)) return false;
    if (!java.util.Objects.equals(mtime, that.mtime)) return false;
    if (!java.util.Objects.equals(nlink, that.nlink)) return false;
    if (!java.util.Objects.equals(perm, that.perm)) return false;
    if (!java.util.Objects.equals(rdev, that.rdev)) return false;
    if (!java.util.Objects.equals(size, that.size)) return false;
    if (!java.util.Objects.equals(uid, that.uid)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(atime,  blocks,  ctime,  gid,  ino,  kind,  mtime,  nlink,  perm,  rdev,  size,  uid,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (atime != null) { sb.append("atime:"); sb.append(atime + ","); }
    if (blocks != null) { sb.append("blocks:"); sb.append(blocks + ","); }
    if (ctime != null) { sb.append("ctime:"); sb.append(ctime + ","); }
    if (gid != null) { sb.append("gid:"); sb.append(gid + ","); }
    if (ino != null) { sb.append("ino:"); sb.append(ino + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (mtime != null) { sb.append("mtime:"); sb.append(mtime + ","); }
    if (nlink != null) { sb.append("nlink:"); sb.append(nlink + ","); }
    if (perm != null) { sb.append("perm:"); sb.append(perm + ","); }
    if (rdev != null) { sb.append("rdev:"); sb.append(rdev + ","); }
    if (size != null) { sb.append("size:"); sb.append(size + ","); }
    if (uid != null) { sb.append("uid:"); sb.append(uid); }
    sb.append("}");
    return sb.toString();
  }
  public class AtimeNested<N> extends TimespecFluent<AtimeNested<N>> implements Nested<N>{
    AtimeNested(Timespec item) {
      this.builder = new TimespecBuilder(this, item);
    }
    TimespecBuilder builder;
    
    public N and() {
      return (N) AttrOverrideSpecFluent.this.withAtime(builder.build());
    }
    
    public N endAtime() {
      return and();
    }
    
  
  }
  public class CtimeNested<N> extends TimespecFluent<CtimeNested<N>> implements Nested<N>{
    CtimeNested(Timespec item) {
      this.builder = new TimespecBuilder(this, item);
    }
    TimespecBuilder builder;
    
    public N and() {
      return (N) AttrOverrideSpecFluent.this.withCtime(builder.build());
    }
    
    public N endCtime() {
      return and();
    }
    
  
  }
  public class MtimeNested<N> extends TimespecFluent<MtimeNested<N>> implements Nested<N>{
    MtimeNested(Timespec item) {
      this.builder = new TimespecBuilder(this, item);
    }
    TimespecBuilder builder;
    
    public N and() {
      return (N) AttrOverrideSpecFluent.this.withMtime(builder.build());
    }
    
    public N endMtime() {
      return and();
    }
    
  
  }

}
